**********************************************
p2k: utilities for paleoclimate reconstruction
**********************************************

`p2k` aims to provide a toolbox for climate field reconstruction (CFR).
It includes convenient workflows for the analysis and visualization of proxies and climate fields.

Documentation
=============

+ Homepage: https://fzhu2e.github.io/p2k
+ Installation: https://fzhu2e.github.io/p2k/ug-installation.html